Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7936)

Unified Diff: chrome/installer/util/logging_installer.cc

Issue 18383003: Move DeleteAfterReboot and Move to base namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/installer/util/delete_tree_work_item.cc ('k') | chrome/installer/util/move_tree_work_item.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/util/logging_installer.cc
diff --git a/chrome/installer/util/logging_installer.cc b/chrome/installer/util/logging_installer.cc
index b6c28b9fb9e63ece192d6c5780d644b46200d9cb..adb01721ed30dcd817d3fcc6db0051a3ead035f3 100644
--- a/chrome/installer/util/logging_installer.cc
+++ b/chrome/installer/util/logging_installer.cc
@@ -47,8 +47,8 @@ TruncateResult TruncateLogFileIfNeeded(const base::FilePath& log_file) {
if (old_log_file.IsValid()) {
result = LOGFILE_DELETED;
base::FilePath tmp_log(log_file.value() + FILE_PATH_LITERAL(".tmp"));
- // Note that file_util::Move will attempt to replace existing files.
- if (file_util::Move(log_file, tmp_log)) {
+ // Note that base::Move will attempt to replace existing files.
+ if (base::Move(log_file, tmp_log)) {
int64 offset = log_size - kTruncatedInstallerLogFileSize;
std::string old_log_data(kTruncatedInstallerLogFileSize, 0);
int bytes_read = base::ReadPlatformFile(old_log_file,
« no previous file with comments | « chrome/installer/util/delete_tree_work_item.cc ('k') | chrome/installer/util/move_tree_work_item.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698